@@ -60,7 +60,7 @@ class DecryptVerifyOperationWidget : public QWidget
     Q_PROPERTY(QString inputFileName READ inputFileName WRITE setInputFileName)
     Q_PROPERTY(QString signedDataFileName READ signedDataFileName WRITE setSignedDataFileName)
 public:
-    explicit DecryptVerifyOperationWidget(QWidget *parent = Q_NULLPTR);
+    explicit DecryptVerifyOperationWidget(QWidget *parent = nullptr);
     ~DecryptVerifyOperationWidget();
 
     enum Mode {
